@@ -7,6 +7,7 @@ match_extra_args <- function(f,
                              .ref_group = NULL,
                              .alt_df_row = NULL,
                              .alt_df = NULL,
+                             .alt_df_full = NULL,
                              .ref_full = NULL,
                              .in_ref_col = NULL,
                              .spl_context = NULL,
@@ -40,6 +41,11 @@ match_extra_args <- function(f,
   if (!is.null(.alt_df)) {
     possargs <- c(possargs, list(.alt_df = .alt_df))
   }
+
+  if (!is.null(.alt_df_full)) {
+    possargs <- c(possargs, list(.alt_df_full = .alt_df_full))
+  }
+
   if (!is.null(.ref_full)) {
     possargs <- c(possargs, list(.ref_full = .ref_full))
   }
@@ -67,9 +73,9 @@ match_extra_args <- function(f,
 }
 
 #' @noRd
-#' @return a RowsVerticalSection object representing the k x 1 section of the
-#'   table being generated, with k the number of rows the analysis function
-#'   generates
+#' @return A `RowsVerticalSection` object representing the `k x 1` section of the
+#'   table being generated, with `k` the number of rows the analysis function
+#'   generates.
 gen_onerv <- function(csub, col, count, cextr, cpath,
                       dfpart, func, totcount, splextra,
                       all_col_exprs,
@@ -77,6 +83,7 @@ gen_onerv <- function(csub, col, count, cextr, cpath,
                       takesdf = .takes_df(func),
                       baselinedf,
                       alt_dfpart,
+                      alt_df_full,
                       inclNAs,
                       col_parent_inds,
                       spl_context) {
@@ -143,6 +150,7 @@ gen_onerv <- function(csub, col, count, cextr, cpath,
     .ref_group = baselinedf,
     .alt_df_row = alt_dfpart,
     .alt_df = alt_dfpart_fil,
+    .alt_df_full = alt_df_full,
     .ref_full = fullrefcoldat,
     .in_ref_col = inrefcol,
     .N_row = NROW(dfpart),
@@ -156,7 +164,6 @@ gen_onerv <- function(csub, col, count, cextr, cpath,
 
   args <- c(args, exargs)
 
-
   val <- do.call(func, args)
   if (!is(val, "RowsVerticalSection")) {
     if (!is(val, "list")) {
@@ -173,17 +180,14 @@ gen_onerv <- function(csub, col, count, cextr, cpath,
   ret
 }
 
-
 strip_multivar_suffix <- function(x) {
   gsub("\\._\\[\\[[0-9]\\]\\]_\\.$", "", x)
 }
 
-
 ## Generate all values (one for each column) for one or more rows
 ## by calling func once per column (as defined by cinfo)
 #' @noRd
-#' @return A list of m RowsVerticalSection objects, one for each
-#' (leaf) column in the table.
+#' @return A list of `m` `RowsVerticalSection` objects, one for each (leaf) column in the table.
 gen_rowvalues <- function(dfpart,
                           datcol,
                           cinfo,
@@ -192,8 +196,9 @@ gen_rowvalues <- function(dfpart,
                           takesdf = NULL,
                           baselines,
                           alt_dfpart,
+                          alt_df_full,
                           inclNAs,
-                          spl_context = spl_context) {
+                          spl_context) {
   colexprs <- col_exprs(cinfo)
   colcounts <- col_counts(cinfo)
   colextras <- col_extra_args(cinfo, NULL)
@@ -204,7 +209,6 @@ gen_rowvalues <- function(dfpart,
 
   colleaves <- collect_leaves(cinfo@tree_layout)
 
-
   gotflist <- is.list(func)
 
   ## one set of named args to be applied to all columns
@@ -214,7 +218,6 @@ gen_rowvalues <- function(dfpart,
     length(splextra) <- ncol(cinfo)
   }
 
-
   if (!gotflist) {
     func <- list(func)
   } else if (length(splextra) == 1) {
@@ -292,6 +295,7 @@ gen_rowvalues <- function(dfpart,
     splextra = exargs,
     MoreArgs = list(
       dfpart = dfpart,
+      alt_df_full = alt_df_full,
       totcount = totcount,
       inclNAs = inclNAs,
       spl_context = spl_context
@@ -299,21 +303,19 @@ gen_rowvalues <- function(dfpart,
     SIMPLIFY = FALSE
   )
 
-
   names(rawvals) <- names(colexprs)
   rawvals
 }
 
-
-
 .strip_lst_rvals <- function(lst) {
   lapply(lst, rawvalues)
 }
 
 #' @noRd
-#' @return a list of table rows, even when only one is generated
+#' @return A list of table rows, even when only one is generated.
 .make_tablerows <- function(dfpart,
                             alt_dfpart,
+                            alt_df_full,
                             func,
                             cinfo,
                             datcol = NULL,
@@ -348,6 +350,7 @@ gen_rowvalues <- function(dfpart,
 
   rawvals <- gen_rowvalues(dfpart,
     alt_dfpart = alt_dfpart,
+    alt_df_full = alt_df_full,
     datcol = datcol,
     cinfo = cinfo,
     func = func,
@@ -423,8 +426,6 @@ gen_rowvalues <- function(dfpart,
     formatvec <- rep(format, length.out = ncrows)
   }
 
-
-
   trows <- lapply(1:ncrows, function(i) {
     rowvals <- lapply(unwrapped_vals, function(colvals) {
       colvals[[i]]
@@ -486,7 +487,7 @@ gen_rowvalues <- function(dfpart,
 }
 
 # Makes content table xxx renaming
-.make_ctab <- function(df, 
+.make_ctab <- function(df,
                        lvl, ## treepos,
                        name,
                        label,
@@ -498,6 +499,7 @@ gen_rowvalues <- function(dfpart,
                        cvar = NULL,
                        inclNAs,
                        alt_df,
+                       alt_df_full,
                        extra_args,
                        spl_context = context_df_row(cinfo = cinfo)) {
   if (length(cvar) == 0 || is.na(cvar) || identical(nchar(cvar), 0L)) {
@@ -518,6 +520,7 @@ gen_rowvalues <- function(dfpart,
         ),
         inclNAs = FALSE,
         alt_dfpart = alt_df,
+        alt_df_full = alt_df_full,
         splextra = extra_args,
         spl_context = spl_context
       ),
@@ -530,7 +533,6 @@ gen_rowvalues <- function(dfpart,
         call. = FALSE
       )
     }
-    
   } else {
     contkids <- list()
   }
@@ -548,9 +550,9 @@ gen_rowvalues <- function(dfpart,
   ctab
 }
 
-
 .make_analyzed_tab <- function(df,
                                alt_df,
+                               alt_df_full,
                                spl,
                                cinfo,
                                partlabel = "",
@@ -575,15 +577,16 @@ gen_rowvalues <- function(dfpart,
       splextra = split_exargs(spl),
       baselines = baselines,
       alt_dfpart = alt_df,
+      alt_df_full = alt_df_full,
       inclNAs = avar_inclNAs(spl),
       spl_context = spl_context
     ),
     error = function(e) e
   )
-  
+
   # Adding section_div for DataRows (analyze leaves)
-  kids <- .set_kids_section_div(kids, spl_section_div(spl), "DataRow")
-  
+  # kids <- .set_kids_section_div(kids, spl_section_div(spl), "DataRow")
+
   if (is(kids, "error")) {
     stop("Error applying analysis function (var - ",
       spl_payload(spl) %||% "colvars", "): ", kids$message,
@@ -601,18 +604,18 @@ gen_rowvalues <- function(dfpart,
     cinfo = cinfo,
     format = obj_format(spl),
     na_str = obj_na_str(spl),
-    indent_mod = indent_mod(spl)
+    indent_mod = indent_mod(spl),
+    trailing_section_div = spl_section_div(spl)
   )
 
   labelrow_visible(ret) <- dolab
   ret
 }
 
-#' @noRd
-#' @param \dots ALL arguments to recurse_applysplit, methods may only use some
-#'   of them.
-#' @return list of children to place at this level
+#' @param ... all arguments to `recurse_applysplit`, methods may only use some of them.
+#' @return A `list` of children to place at this level.
 #'
+#' @noRd
 setGeneric(".make_split_kids", function(spl, have_controws, make_lrow, ...) {
   standardGeneric(".make_split_kids")
 })
@@ -626,6 +629,7 @@ setMethod(
            ...,
            df,
            alt_df,
+           alt_df_full,
            lvl,
            name,
            cinfo,
@@ -640,6 +644,7 @@ setMethod(
     ret <- .make_analyzed_tab(
       df = df,
       alt_df,
+      alt_df_full = alt_df_full,
       spl = spl,
       cinfo = cinfo,
       lvl = lvl + 1L,
@@ -693,6 +698,8 @@ setMethod(
       ...
     ))
 
+    kids <- .set_kids_section_div(kids, spl_section_div(spl), "VTableTree")
+
     ## XXX this seems like it should be identical not !identical
     ## TODO FIXME
     if (!identical(make_lrow, FALSE) && !have_controws && length(kids) == 1) {
@@ -732,7 +739,6 @@ setMethod(
   }
 )
 
-
 setMethod(
   ".make_split_kids", "Split",
   function(spl,
@@ -742,6 +748,7 @@ setMethod(
            splvec, ## passed to recursive_applysplit
            df, ## used to apply split
            alt_df, ## used to apply split for alternative df
+           alt_df_full, ## passed to recursive_applysplit
            lvl, ## used to calculate innerlev
            cinfo, ## used for sanity check
            baselines, ## used to calc new baselines
@@ -760,7 +767,6 @@ setMethod(
       nms <- as.character(nms)
     }
 
-    ##
     ## Get new baseline values
     ##
     ## XXX this is a lot of data churn, if it proves too slow
@@ -915,6 +921,7 @@ setMethod(
         recursive_applysplit(
           df = dfpart,
           alt_df = alt_dfpart,
+          alt_df_full = alt_df_full,
           name = nm,
           lvl = innerlev,
           splvec = splvec,
@@ -940,12 +947,14 @@ setMethod(
       splval = splvals,
       SIMPLIFY = FALSE
     ))
-    
+
     # Setting the kids section separator if they inherits VTableTree
-    inner <- .set_kids_section_div(inner, 
-                                   trailing_section_div_char = spl_section_div(spl), 
-                                   allowed_class = "VTableTree")
-    
+    inner <- .set_kids_section_div(
+      inner,
+      trailing_section_div_char = spl_section_div(spl),
+      allowed_class = "VTableTree"
+    )
+
     ## This is where we need to build the structural tables
     ## even if they are invisible because their labels are not
     ## not shown.
@@ -1002,10 +1011,10 @@ context_df_row <- function(split = character(),
   ret
 }
 
-
 recursive_applysplit <- function(df,
                                  lvl = 0L,
                                  alt_df,
+                                 alt_df_full,
                                  splvec,
                                  name,
                                  #         label,
@@ -1045,6 +1054,7 @@ recursive_applysplit <- function(df,
     indent_mod = cindent_mod,
     cvar = cvar,
     alt_df = alt_df,
+    alt_df_full = alt_df_full,
     extra_args = cextra_args,
     spl_context = spl_context
   )
@@ -1074,6 +1084,7 @@ recursive_applysplit <- function(df,
       spl = spl,
       df = df,
       alt_df = alt_df,
+      alt_df_full = alt_df_full,
       lvl = lvl,
       splvec = splvec,
       name = name,
@@ -1138,50 +1149,38 @@ recursive_applysplit <- function(df,
   ret
 }
 
-
-
 #' Create a table from a layout and data
 #'
-#' Layouts are used to describe a table pre-data. `build_table` is used to
-#' create a table using a layout and a dataset.
-#'
+#' Layouts are used to describe a table pre-data. `build_table` is used to create a table
+#' using a layout and a dataset.
 #'
 #' @inheritParams gen_args
 #' @inheritParams lyt_args
-#' @param col_counts numeric (or `NULL`). Deprecated. If non-null, column counts
-#'   which override those calculated automatically during tabulation. Must
-#'   specify "counts" for \emph{all} resulting columns if non-NULL. \code{NA}
-#'   elements will be replaced with the automatically calculated counts.
-#' @param col_total integer(1). The total observations across all columns.
-#'   Defaults to \code{nrow(df)}.
-#' @param \dots currently ignored.
+#' @param col_counts (`numeric` or `NULL`)\cr `r lifecycle::badge("deprecated")` if non-`NULL`, column counts
+#'   *for leaf-columns only* which override those calculated automatically during tabulation. Must specify
+#'   "counts" for *all* leaf-columns if non-`NULL`. `NA` elements will be replaced with the automatically
+#'   calculated counts. Turns on display of leaf-column counts when non-`NULL`.
+#' @param col_total (`integer(1)`)\cr the total observations across all columns. Defaults to `nrow(df)`.
+#' @param ... ignored.
 #'
 #' @details
-#'
-#' When \code{alt_counts_df} is specified, column counts are calculated by
-#' applying the exact column subsetting expressions determined when applying
-#' column splitting to the main data (\code{df}) to \code{alt_counts_df} and
+#' When `alt_counts_df` is specified, column counts are calculated by applying the exact column subsetting
+#' expressions determined when applying column splitting to the main data (`df`) to `alt_counts_df` and
 #' counting the observations in each resulting subset.
 #'
-#' In particular, this means that in the case of splitting based on cuts of the
-#' data, any dynamic cuts will have been calculated based on \code{df} and
-#' simply re-used for the count calculation.
+#' In particular, this means that in the case of splitting based on cuts of the data, any dynamic cuts will have
+#' been calculated based on `df` and simply re-used for the count calculation.
 #'
-#' @note When overriding the column counts or totals care must be taken that,
-#'   e.g., `length()` or `nrow()` are not called within tabulation functions,
-#'   because those will NOT give the overridden counts. Writing/using tabulation
-#'   functions which accept \code{.N_col} and \code{.N_total} or do not rely on
-#'   column counts at all (even implicitly) is the only way to ensure overridden
-#'   counts are fully respected.
+#' @note
+#' When overriding the column counts or totals care must be taken that, e.g., `length()` or `nrow()` are not called
+#' within tabulation functions, because those will NOT give the overridden counts. Writing/using tabulation
+#' functions which accept `.N_col` and `.N_total` or do not rely on column counts at all (even implicitly) is the
+#' only way to ensure overridden counts are fully respected.
 #'
-#' @export
-#' @return A \code{TableTree} or \code{ElementaryTable} object representing the
-#'   table created by performing the tabulations declared in \code{lyt} to the
-#'   data \code{df}.
-#' @author Gabriel Becker
+#' @return A `TableTree` or `ElementaryTable` object representing the table created by performing the tabulations
+#'   declared in `lyt` to the data `df`.
 #'
 #' @examples
-#'
 #' lyt <- basic_table() %>%
 #'   split_cols_by("Species") %>%
 #'   analyze("Sepal.Length", afun = function(x) {
@@ -1190,7 +1189,6 @@ recursive_applysplit <- function(df,
 #'       "range" = diff(range(x))
 #'     )
 #'   })
-#'
 #' lyt
 #'
 #' tbl <- build_table(lyt, iris)
@@ -1232,6 +1230,9 @@ recursive_applysplit <- function(df,
 #'
 #' tbl6 <- build_table(lyt3, DM, col_counts = 1:3)
 #' tbl6
+#'
+#' @author Gabriel Becker
+#' @export
 build_table <- function(lyt, df,
                         alt_counts_df = NULL,
                         col_counts = NULL,
@@ -1264,7 +1265,7 @@ build_table <- function(lyt, df,
   if (any(alt_params) && is.null(alt_counts_df)) {
     stop(
       "Layout contains afun/cfun functions that have optional parameters ",
-      ".alt_df and/or .alt_df_row, but no alt_count_df was provided in ",
+      ".alt_df and/or .alt_df_row, but no alt_counts_df was provided in ",
       "build_table()."
     )
   }
@@ -1277,12 +1278,20 @@ build_table <- function(lyt, df,
     topleft
   )
   if (!is.null(col_counts)) {
-    disp_ccounts(cinfo) <- TRUE
+    toreplace <- !is.na(col_counts)
+    newccs <- col_counts(cinfo) ## old actual counts
+    newccs[toreplace] <- col_counts[toreplace]
+    col_counts(cinfo) <- newccs
+    leaf_paths <- col_paths(cinfo)
+    for (pth in leaf_paths) {
+      colcount_visible(cinfo, pth) <- TRUE
+    }
   }
   rlyt <- rlayout(lyt)
   rtspl <- root_spl(rlyt)
   ctab <- .make_ctab(df, 0L,
     alt_df = NULL,
+    alt_df_full = alt_counts_df,
     name = "root",
     label = "",
     cinfo = cinfo, ## cexprs, ctree,
@@ -1293,6 +1302,7 @@ build_table <- function(lyt, df,
     cvar = content_var(rtspl),
     extra_args = content_extra_args(rtspl)
   )
+
   kids <- lapply(seq_along(rlyt), function(i) {
     splvec <- rlyt[[i]]
     if (length(splvec) == 0) {
@@ -1307,6 +1317,7 @@ build_table <- function(lyt, df,
     recursive_applysplit(
       df = df, lvl = 0L,
       alt_df = alt_counts_df,
+      alt_df_full = alt_counts_df,
       name = nm,
       splvec = splvec,
       cinfo = cinfo,
@@ -1330,6 +1341,14 @@ build_table <- function(lyt, df,
   kids <- kids[!sapply(kids, is.null)]
   if (length(kids) > 0) names(kids) <- sapply(kids, obj_name)
 
+  # top level divisor
+  if (!is.na(top_level_section_div(lyt))) {
+    kids <- lapply(kids, function(first_level_kids) {
+      trailing_section_div(first_level_kids) <- top_level_section_div(lyt)
+      first_level_kids
+    })
+  }
+
   if (nrow(ctab) == 0L && length(kids) == 1L && is(kids[[1]], "VTableTree")) {
     tab <- kids[[1]]
     main_title(tab) <- main_title(lyt)
@@ -1356,12 +1375,10 @@ build_table <- function(lyt, df,
     )
   }
 
-
   ## This seems to be unneeded, not clear what 'top_left' check it refers to
   ## but both top_left taller than column headers and very long topleft are now
   ## allowed, so this is just wasted computation.
 
-
   ## ## this is where the top_left check lives right now. refactor later maybe
   ## ## but now just call it so the error gets thrown when I want it to
   ## unused <- matrix_form(tab)
@@ -1566,10 +1583,11 @@ setMethod(
   }
 )
 
-
 splitvec_to_coltree <- function(df, splvec, pos = NULL,
                                 lvl = 1L, label = "",
-                                spl_context = context_df_row(cinfo = NULL)) {
+                                spl_context = context_df_row(cinfo = NULL),
+                                alt_counts_df = df,
+                                global_cc_format) {
   stopifnot(
     lvl <= length(splvec) + 1L,
     is(splvec, "SplitVector")
@@ -1579,15 +1597,20 @@ splitvec_to_coltree <- function(df, splvec, pos = NULL,
   if (lvl == length(splvec) + 1L) {
     ## XXX this should be a LayoutColree I Think.
     nm <- unlist(tail(value_names(pos), 1)) %||% ""
+    spl <- tail(pos_splits(pos), 1)[[1]]
+    fmt <- colcount_format(spl) %||% global_cc_format
     LayoutColLeaf(
       lev = lvl - 1L,
       label = label,
       tpos = pos,
-      name = nm
+      name = nm,
+      colcount = NROW(alt_counts_df),
+      disp_ccounts = disp_ccounts(spl),
+      colcount_format = fmt
     )
   } else {
     spl <- splvec[[lvl]]
-    nm <- if (is.null(pos)) {
+    nm <- if (is.null(pos) || length(pos_splits(pos)) == 0) {
       obj_name(spl)
     } else {
       unlist(tail(
@@ -1603,31 +1626,62 @@ splitvec_to_coltree <- function(df, splvec, pos = NULL,
     vals <- rawpart[["values"]]
     labs <- rawpart[["labels"]]
 
-
+    force(alt_counts_df)
     kids <- mapply(
       function(dfpart, value, partlab) {
+        ## we could pass subset expression in here but the spec
+        ## currently doesn't call for it in column space
         newprev <- context_df_row(
           split = obj_name(spl),
           value = value_names(value),
           full_parent_df = list(dfpart),
           cinfo = NULL
         )
+        ## subset expressions handled inside make_child_pos,
+        ## value is (optionally, for the moment) carrying it around
         newpos <- make_child_pos(pos, spl, value, partlab)
+        acdf_subset_expr <- make_subset_expr(spl, value)
+        new_acdf_subset <- try(eval(acdf_subset_expr, alt_counts_df), silent = TRUE)
+        if (is(new_acdf_subset, "try-error")) {
+          stop(sprintf(
+            paste(
+              ifelse(identical(df, alt_counts_df), "df", "alt_counts_df"),
+              "appears incompatible with column-split",
+              "structure. Offending column subset",
+              "expression: %s\nOriginal error",
+              "message: %s"
+            ), deparse(acdf_subset_expr[[1]]),
+            conditionMessage(attr(new_acdf_subset, "condition"))
+          ))
+        }
+
         splitvec_to_coltree(dfpart, splvec, newpos,
           lvl + 1L, partlab,
-          spl_context = rbind(spl_context, newprev)
+          spl_context = rbind(spl_context, newprev),
+          alt_counts_df = alt_counts_df[new_acdf_subset, , drop = FALSE],
+          global_cc_format = global_cc_format
         )
       },
       dfpart = datparts, value = vals,
       partlab = labs, SIMPLIFY = FALSE
     )
+    disp_cc <- FALSE
+    cc_format <- global_cc_format # this doesn't matter probably, but its technically more correct
+    if (lvl > 1) {
+      disp_cc <- disp_ccounts(splvec[[lvl - 1]])
+      cc_format <- colcount_format(splvec[[lvl - 1]]) %||% global_cc_format
+    }
+
     names(kids) <- value_names(vals)
     LayoutColTree(
       lev = lvl, label = label,
       spl = spl,
       kids = kids, tpos = pos,
       name = nm,
-      summary_function = content_fun(spl)
+      summary_function = content_fun(spl),
+      colcount = NROW(alt_counts_df),
+      disp_ccounts = disp_cc,
+      colcount_format = cc_format
     )
   }
 }
@@ -1638,6 +1692,7 @@ splitvec_to_coltree <- function(df, splvec, pos = NULL,
 ## labelrows should be visible for ElementaryTables
 ## generatead from analyzing a single variable
 setGeneric("fix_analyze_vis", function(lyt) standardGeneric("fix_analyze_vis"))
+
 setMethod(
   "fix_analyze_vis", "PreDataTableLayouts",
   function(lyt) {
@@ -1645,6 +1700,7 @@ setMethod(
     lyt
   }
 )
+
 setMethod(
   "fix_analyze_vis", "PreDataRowLayout",
   function(lyt) {
@@ -1690,6 +1746,7 @@ setMethod(
 )
 
 # check_afun_cfun_params ----
+
 # This checks if the input params are used anywhere in cfun/afun
 setGeneric("check_afun_cfun_params", function(lyt, params) {
   standardGeneric("check_afun_cfun_params")
@@ -1749,7 +1806,8 @@ setMethod(
   }
 )
 
-# Helper fnc ----
+# Helper functions ----
+
 count <- function(df, ...) NROW(df)
 
 guess_format <- function(val) {
@@ -1832,61 +1890,51 @@ n_cells_res <- function(res) {
   ans
 }
 
-#' Generalized Frequency Table
+#' Generalized frequency table
 #'
-#' @description This function provides a convenience interface for
-#' generating generalizations of a 2-way frequency table. Row and column
-#' space can be facetted by variables, and an analysis function can be specified.
+#' This function provides a convenience interface for generating generalizations of a 2-way frequency table. Row and
+#' column space can be facetted by variables, and an analysis function can be specified. The function then builds a
+#' layout with the specified layout and applies it to the data provided.
 #'
-#' The function then builds a layout with the specified layout and applies it to
-#' the data provided.
-#'
-#' @param row_vars character. The names of variables to be used in row facetting.
-#' @param col_vars character. The names of variables to be used in column facetting.
-#' @param data data.frame. The data to tabulate.
-#' @param avar character(1). The variable to be analyzed. Defaults to the first variable in `data`.
-#' @param row_labels character or NULL. Row label(s) which should be applied to the analysis rows. length must match
-#'   the number of rows generated by `afun`. See details.
-#' @param afun function. The function to generate the analysis row cell values. This can be a proper analysis
-#'   function, or a function which returns a vector or list. Vectors are taken as multi-valued single cells, whereas
-#'   lists are interpreted as multiple cells.
-#' @param drop_levels logical(1). Should unobserved factor levels be dropped during facetting. Defaults to `TRUE`.
-#' @param summarize_groups logical(1). Should each level of nesting include marginal summary rows. Defaults to `FALSE`
-#' @param ... passed to `afun`, if specified. Otherwise ignored.
-#' @param .default_rlabel character(1). This is an implementation detail that should not be set by end users.
 #' @inheritParams constr_args
 #' @inheritParams basic_table
+#' @param row_vars (`character`)\cr the names of variables to be used in row facetting.
+#' @param col_vars (`character`)\cr the names of variables to be used in column facetting.
+#' @param data (`data.frame`)\cr the data to tabulate.
+#' @param avar (`string`)\cr the variable to be analyzed. Defaults to the first variable in `data`.
+#' @param row_labels (`character` or `NULL`)\cr row label(s) which should be applied to the analysis rows. Length must
+#'   match the number of rows generated by `afun`.
+#' @param afun (`function`)\cr the function to generate the analysis row cell values. This can be a proper analysis
+#'   function, or a function which returns a vector or list. Vectors are taken as multi-valued single cells, whereas
+#'   lists are interpreted as multiple cells.
+#' @param drop_levels (`flag`)\cr whether unobserved factor levels should be dropped during facetting. Defaults to
+#'   `TRUE`.
+#' @param summarize_groups (`flag`)\cr whether each level of nesting should include marginal summary rows. Defaults to
+#'   `FALSE`.
+#' @param ... additional arguments passed to `afun`.
+#' @param .default_rlabel (`string`)\cr this is an implementation detail that should not be set by end users.
 #'
 #' @details
+#' This function creates a table with a single top-level structure in both row and column dimensions involving faceting
+#' by 0 or more variables in each dimension.
 #'
-#' This function creates a table  with a single top-level structure in
-#' both row and column dimensions  involving faceting by 0 or more
-#' variables in each.
+#' The display of the table depends on certain details of the tabulation. In the case of an `afun` which returns a
+#' single cell's contents (either a scalar or a vector of 2 or 3 elements), the label rows for the deepest-nested row
+#' facets will be hidden and the labels used there will be used as the analysis row labels. In the case of an `afun`
+#' which returns a list (corresponding to multiple cells), the names of the list will be used as the analysis row
+#' labels and the deepest-nested facet row labels will be visible.
 #'
-#' The display  of the table depends on certain
-#' details  of the  tabulation.   In  the case  of  an `afun` which
-#' returns a single  cell's contents (either a scalar  or a vector
-#' of 2 or 3 elements), the  label rows for the deepest-nested row
-#' facets will be hidden and the labels used there will be used as
-#' the analysis row labels. In the case of an `afun` which returns a
-#' list (corresponding to  multiple cells), the names  of the list
-#' will be used as the analysis  row labels and the deepest-nested
-#' facet row labels will be visible.
+#' The table will be annotated in the top-left area with an informative label displaying the analysis variable
+#' (`avar`), if set, and the function used (captured via substitute) where possible, or 'count' if not. One exception
+#' where the user may directly modify the top-left area (via `row_labels`) is the case of a table with row facets and
+#' an `afun` which returns a single row.
 #'
-#' The  table  will  be  annotated   in  the  top-left  area  with  an
-#' informative  label displaying  the analysis  variable (`avar`),  if
-#' set,  and  the  function   used  (captured  via  substitute)  where
-#' possible, or 'count' if not. One exception where the user may
-#' directly modify the top-left area (via `row_labels`) is the case of
-#' a table with row facets and an `afun` which returns a single row.
-#'
-#'
-#' @return for `qtable` a built TableTree object representing the desired table,
-#' for `qtable_layout`, a `PreDataTableLayouts` object declaring the structure of
-#' the desired table, suitable for passing to `build_table`.
+#' @return
+#' * `qtable` returns a built `TableTree` object representing the desired table
+#' * `qtable_layout` returns a `PreDataTableLayouts` object declaring the structure of the desired table, suitable for
+#'   passing to [build_table()].
 #'
 #' @examples
-#'
 #' qtable(ex_adsl)
 #' qtable(ex_adsl, row_vars = "ARM")
 #' qtable(ex_adsl, col_vars = "ARM")
@@ -1902,6 +1950,7 @@ n_cells_res <- function(res) {
 #'   row_vars = "SEX",
 #'   col_vars = "ARM", avar = "AGE", afun = range
 #' ))
+#'
 #' @export
 qtable_layout <- function(data,
                           row_vars = character(),
@@ -1969,7 +2018,6 @@ qtable_layout <- function(data,
     row_labels <- dflt_row_lbl
   }
 
-
   lyt <- basic_table(
     title = title,
     subtitles = subtitles,
